==> deepin-log-viewer_5.9.3.orig.tar.xz: deepin-log-viewer-5.9.3/translations/deepin-log-viewer_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Shfaqe në përgjegjës kartelash</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Spastroje regjistrin</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Rifreskoje</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Jeni i sigurt se doni të spastrohet regjistri?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Ripohojeni</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Krejt</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Sot</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 ditë</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 javë</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 muaj</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 muaj</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Eksportoje</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksportoje</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Krejt</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgjencë</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Sinjalizim</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Kujdes</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Njoftim</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Të dhëna</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Diagnostikoje</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Hyrje</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Nisje</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Fikje</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Superkritik</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ndiqe</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEKS (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Po eksportohet…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Eksportim i suksesshëm</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Eksportimi dështoi</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Eksporto Kartelë</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Periudhë:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Listë aplikacionesh:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Gjendje:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Lloj Akti:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Përdorues:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Veprim:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Emër përdoruesi:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Zë nisjesh</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Zë fikjesh</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Zë hyrjesh</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Kujdes</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Diagnostikoje</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgjencë</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Sinjalizim</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Njoftim</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ndiqe</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Superkritik</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Kartela regjistër është e zbrazët</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Parës Regjistri</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Parësi i Regjistrave është një mjet i dobishëm për parje regjistrash sistemi.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>S’ka përfundime kërkimi</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Datë dhe Kohë</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Përdorues</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Burim</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Veprim</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Gjendje</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Lloj Akti</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proces:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Datë dhe Kohë:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User:</source>
        <translation>Përdorues:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Datë dhe Kohë</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Regjistër Sistemi</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Regjistër Kerneli</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Regjistër Nisjesh</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Regjistër dpkg-je</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Regjistër Kwin-i</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Regjistër Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Regjistër Aplikacionesh</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Akt Nisjeje-Fikjeje</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Regjistër dnf-je</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.0.7.orig.tar.xz: deepin-log-viewer-6.0.7/translations/deepin-log-viewer_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Shfaqe në përgjegjës kartelash</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Spastroje regjistrin</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Rifreskoje</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Jeni i sigurt se doni të spastrohet regjistri?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Ripohojeni</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Krejt</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Sot</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 ditë</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 javë</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 muaj</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 muaj</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Eksportoje</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksportoje</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Krejt</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgjencë</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Sinjalizim</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Kujdes</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Njoftim</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Të dhëna</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Diagnostikoje</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Hyrje</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Nisje</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Fikje</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Superkritik</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ndiqe</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEKS (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Po eksportohet…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Eksportim i suksesshëm</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Eksportimi dështoi</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Eksporto Kartelë</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Periudhë:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Listë aplikacionesh:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Gjendje:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Lloj Akti:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Përdorues:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Veprim:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Emër përdoruesi:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Zë nisjesh</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Zë fikjesh</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Zë hyrjesh</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Kujdes</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Diagnostikoje</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgjencë</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Sinjalizim</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Njoftim</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ndiqe</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Superkritik</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Kartela regjistër është e zbrazët</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Parës Regjistri</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Parësi i Regjistrave është një mjet i dobishëm për parje regjistrash sistemi.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>S’ka përfundime kërkimi</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Datë dhe Kohë</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Përdorues</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Burim</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Veprim</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Gjendje</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Lloj Akti</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proces:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Datë dhe Kohë:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User:</source>
        <translation>Përdorues:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Datë dhe Kohë</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Regjistër Sistemi</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Regjistër Kerneli</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Regjistër Nisjesh</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Regjistër dpkg-je</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Regjistër Kwin-i</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Regjistër Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Regjistër Aplikacionesh</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Akt Nisjeje-Fikjeje</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Regjistër dnf-je</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Interval rifreskimi</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 sek.</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min.</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Pa rifreskim</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Eksportoji Krejt</translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation>Regjistra Sistemi</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Rifreskoje Tani</translation>
    </message>
</context>
</TS>
